package de.frajul.endlessroll.main.tutorial;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Created by Julian on 14.03.2017.
 */

public class Tutorial {

    private int levelId, levelPackId;
    private List<BreakPoint> breakPoints;
    protected List<BreakPoint> currentBreakPoints = new ArrayList<>();

    public Tutorial(int levelId, int levelPackId, BreakPoint... breakPoints) {
        this.levelId = levelId;
        this.levelPackId = levelPackId;
        this.breakPoints = Arrays.asList(breakPoints);
    }

    public void reset() {
        for (BreakPoint breakPoint : breakPoints)
            breakPoint.setAlreadyShown(false);
        currentBreakPoints.clear();
    }

    public void onLevelFinished() {
        currentBreakPoints.clear();

        for (BreakPoint breakPoint : breakPoints) {
            if (breakPoint.getX() == BreakPoint.LEVEL_FINISHED_X) {
                breakPoint.setAlreadyShown(true);
                currentBreakPoints.add(breakPoint);
            }
        }
    }

    public void update(float playerProgress) {
        playerProgress *= 2f;
        currentBreakPoints.clear();

        for (BreakPoint breakPoint : breakPoints) {
            if (!breakPoint.isAlreadyShown() && playerProgress >= breakPoint.getX() && breakPoint
                    .getX() != BreakPoint.LEVEL_FINISHED_X) {
                breakPoint.setAlreadyShown(true);
                currentBreakPoints.add(breakPoint);
            }
        }
    }

    public boolean isOverNewBreakPoints() {
        return !currentBreakPoints.isEmpty();
    }

    public List<BreakPoint> getCurrentBreakPoints() {
        return currentBreakPoints;
    }

    public List<BreakPoint> getBreakPoints() {
        return breakPoints;
    }

    public int getLevelId() {
        return levelId;
    }

    public int getLevelPackId() {
        return levelPackId;
    }
}